#!/usr/bin/env node
import { Server } from "@modelcontextprotocol/sdk/server/index.js";
import { StdioServerTransport, } from "@modelcontextprotocol/sdk/server/stdio.js";
import { CallToolRequestSchema, ListToolsRequestSchema, ToolSchema } from "@modelcontextprotocol/sdk/types.js";
import * as A from 'wowok_agent';
const ToolInputSchema = ToolSchema.shape.inputSchema;
const ToolOutputSchema = ToolSchema.shape.outputSchema;
A.WOWOK.Protocol.Instance().use_network(A.WOWOK.ENTRYPOINT.testnet);
// Create server instance
const server = new Server({
    name: "wowok_service_mcp_server",
    version: "1.2.42",
    description: `${A.CallServiceSchemaDescription} - A server for handling Service calls in the WOWOK protocol. ${A.NoticeFieldsOrder}`,
}, {
    capabilities: {
        prompts: {},
        resources: {},
        tools: {},
        logging: {},
        tokensOptimized: true, // Optimize tokens for better performance and efficiency.
    },
});
async function main() {
    const TOOLS = [
        {
            name: A.ToolName.OP_SERVICE,
            description: A.CallServiceSchemaDescription,
            inputSchema: A.CallServiceSchemaInput(),
        },
    ];
    const transport = new StdioServerTransport();
    server.setRequestHandler(ListToolsRequestSchema, async () => {
        return { tools: TOOLS };
    });
    server.setRequestHandler(CallToolRequestSchema, async (request) => {
        try {
            if (!request.params.arguments) {
                throw new Error("Arguments are required");
            }
            switch (request.params.name) {
                case A.ToolName.OP_SERVICE: {
                    const args = A.CallServiceSchema.parse(request.params.arguments);
                    return { content: [{ type: "text", text: A.ObjectOperationResult(await A.call_service(args)) }] };
                }
                default:
                    throw new Error(`Unknown tool: ${request.params.name}`);
            }
        }
        catch (error) {
            throw new Error(`Invalid input: ${JSON.stringify(error)}`);
        }
    });
    await server.connect(transport);
    // Cleanup on exit
    process.on("SIGINT", async () => {
        await cleanup();
        await server.close();
        process.exit(0);
    });
}
async function cleanup() {
}
main().catch((error) => {
    process.exit(1);
});
process.stdin.on("close", async () => {
    await cleanup();
    await server.close();
    process.exit(0);
});
